#!/bin/sh
#
#  $Id: disam_select.sh,v 1.9 2002/08/22 11:01:05 jason Exp $
#
#  $Log: disam_select.sh,v $
#  Revision 1.9  2002/08/22 11:01:05  jason
#  Changed names of disam libraries to be more meaningful
#
#  Revision 1.8  2002/05/21 08:04:46  jason
#  added cisam descriptions
#
#  Revision 1.7  2001/08/01 07:47:58  jason
#  add additional rm command due to ln -sf not working on siemens
#
#  Revision 1.6  2001/07/31 12:20:12  jason
#  remove options 6, 7 and 8 and add sinix and unixware 2.1.3 platforms
#
#  Revision 1.5  2001/04/27 08:48:47  jason
#  change name of libesdisam to libesisam
#
#  Revision 1.4  2001/04/09 16:00:12  jason
#  change default locking mode
#
#  Revision 1.3  2000/11/08 13:44:44  jason
#  *** empty log message ***
#
#  Revision 1.2  2000/09/27 10:43:38  jason
#  *** empty log message ***
#
#  Revision 1.1  2000/09/26 11:06:22  jason
#  Initial revision
#
#
#
# Which echo?
#
if [ -x /bin/echo ];then
  ECHO="/bin/echo"
else
  if [ -x /usr/bin/echo ];then
    ECHO="/usr/bin/echo"
  else
    cat <<EOF
Cannot even find the echo command
EOF
  exit 1
  fi
fi
#
# echo interprets backslash chrs by default? POSIX says no.
#
test=`$ECHO "fred\c"`
if [ "$test" = "fred\c" ];then
  ECHO="$ECHO -e "
  test=`$ECHO "fred\c"`
  if [ "$test" != "fred" ];then
    cat <<EOF
echo command ($ECHO) does not interpret backslash characters.
You may see backslash c's when asked questions during this install.
You can safely ignore this except in Linux where you may need to
edit /etc/ld.so.conf to remove extra backslash n's from the lines added
by this script.
EOF
  fi
fi
export ECHO         # allow child scripts to see ECHO

LOWERCASE=""
if ( $ECHO "TeSt" | tr '[A-Z]' '[a-z]' 1>/dev/null 2>/dev/null )
then
  lowctest=`$ECHO "TeSt" | tr '[A-Z]' '[a-z]'`
  if [ "$lowctest" = "test" ];then
    LOWERCASE="tr '[A-Z]' '[a-z]'"
  fi
fi
if [ "$LOWERCASE" = "" ];then
  lowctest=`$ECHO "TeSt" | dd conv=lcase`
  if [ "$lowctest" = "test" ];then
    LOWERCASE="dd conv=lcase"
  fi
fi
if [ "$LOWERCASE" = "" ];then
  lowctest=`$ECHO "TeSt" | sed 'y/TES/tes/'`
  if [ "$lowctest" != "test" ];then
    $ECHO "Cannot continue without a working tr, dd or sed command"
    exit 1
  else
    LOWERCASE="sed 'y/ABCDEFGHIJKLMNOPQRSTUVWXYZ/abcdefghijklmnopqrstuvwxyz/'"
  fi
fi
export LOWERCASE

#
# See what platform we are on
# ===========================
#
PLATFORM=`uname -s`
platform=`uname -s | $LOWERCASE`
export platform
osrelease=`uname -r`
osversions=`uname -v`
#
# Platform specific differences
# =============================
#
#
TESTLINK="-L"
TESTEXISTS="-e"
SHARED_EXT=".so"

if [ "$platform" = "aix" ];then
  SHARED_EXT=".a"
fi

if [ "$platform" = "hp-ux" ];then
  SHARED_EXT=".sl"
fi

if [ "$platform" = "sunos" ];then
  TESTEXISTS="-r"
  TESTLINK="-h"
fi

if [ "$platform" = "sco_sv" ];then
  TESTEXISTS="-r"
fi

if [ "$platform" = "unixware" ];then
  TESTEXISTS="-r"
fi

if [ "$platform" = "unix_sv" ];then
  TESTEXISTS="-r"
fi

if [ "$platform" = "freebsd" ];then
  TESTLINK="-h"
fi

if [ "$platform" = "sinix-n" ];then
  TESTEXISTS="-r"
  TESTLINK="-h"
fi


export TESTEXISTS       # make TESTEXISTS available to child scripts
export TESTLINK         # make TESTLINK available to child scripts

#
# Check for root
# ==============
#
uid=`id | awk '{print $1}' | awk -F= '{print $2}' | awk -F\( '{print $1}'`
if [ "$uid" != "0" ];then
    $ECHO "This installation requires you to be the root user."
    $ECHO "Please login as root and try again."
    exit 99
fi

cat <<EOF

Disam Locking Mode Selection

** NOTE : All locking modes may not be available on all platforms **

1. Disam 96 (ISLOCKING = 1 C7LOCKING = 0) (cisam pre 4.1)
2. Disam 96 (ISLOCKING = 2 C7LOCKING = 0) (cisam pre 5.0)
3. Disam 96 (ISLOCKING = 2 C7LOCKING = 1) (cisam 5.0 > 7.1) [default]
4. Disam 96 (ISLOCKING = 2 C7LOCKING = 2) (cisam 7.2)
5. Disam 96 (ISLOCKING = 2 C7LOCKING = 2) (cisam 7.26)

EOF

answer="0"
$ECHO "Select required locking mode? (1-5) [3]: \c"
while [ \( "$answer" != "" \) -a \( "$answer" -lt 1 -o "$answer" -gt 5 \) ]
do
  read answer
  if [ "$answer" = "" ];then
    answer="3"
  fi
  if [ "$answer" = "q" ];then
    $ECHO "Selection terminated"
    exit 99
  fi
done

if [ "$answer" = "1" ];then
  if [ "$TESTEXISTS" libdisam_pre41${SHARED_EXT} ];then
    rm -f libesisam${SHARED_EXT}
    ln -sf libdisam_pre41${SHARED_EXT} libesisam${SHARED_EXT}
    $ECHO "Disam 96 (ISLOCKING = 1 C7LOCKING = 0) (cisam pre 4.1)"
  else
    $ECHO "libdisam_pre41${SHARED_EXT} not found, exiting"
    exit 99
  fi
fi

if [ "$answer" = "2" ];then
  if [ "$TESTEXISTS" libdisam_pre50${SHARED_EXT} ];then
    rm -f libesisam${SHARED_EXT}
    ln -sf libdisam_pre50${SHARED_EXT} libesisam${SHARED_EXT}
    $ECHO "Disam 96 (ISLOCKING = 2 C7LOCKING = 0) (cisam pre 5.0)"
  else
    $ECHO "libdisam_pre50${SHARED_EXT} not found, exiting"
    exit 99
  fi
fi

if [ "$answer" = "3" ];then
  if [ "$TESTEXISTS" libdisam_pre72${SHARED_EXT} ];then
    rm -f libesisam${SHARED_EXT}
    ln -sf libdisam_pre72${SHARED_EXT} libesisam${SHARED_EXT}
    $ECHO "Disam 96 (ISLOCKING = 2 C7LOCKING = 1) (cisam 5.0 > 7.1)"
  else
    $ECHO "libdisam_pre72${SHARED_EXT} not found, exiting"
    exit 99
  fi
fi

if [ "$answer" = "4" ];then
  if [ "$TESTEXISTS" libdisam_72${SHARED_EXT} ];then
    rm -f libesisam${SHARED_EXT}
    ln -sf libdisam_72${SHARED_EXT} libesisam${SHARED_EXT}
    $ECHO "Disam 96 (ISLOCKING = 2 C7LOCKING = 2) (cisam 7.2)"
  else
    $ECHO "libdisam_72${SHARED_EXT} not found, exiting"
    exit 99
  fi
fi

if [ "$answer" = "5" ];then
  if [ "$TESTEXISTS" libdisam_726${SHARED_EXT} ];then
    rm -f libesisam${SHARED_EXT}
    ln -sf libdisam_726${SHARED_EXT} libesisam${SHARED_EXT}
    $ECHO "Disam 96 (ISLOCKING = 2 C7LOCKING = 2) (cisam 7.26)"
  else
    $ECHO "libdisam_726${SHARED_EXT} not found, exiting"
    exit 99
  fi
fi

